summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--src/rebar_eunit.erl3
1 files changed, 2 insertions, 1 deletions
diff --git a/src/rebar_eunit.erl b/src/rebar_eunit.erl
index 9f2baf1..a8ce954 100644
--- a/src/rebar_eunit.erl
+++ b/src/rebar_eunit.erl
@@ -74,8 +74,9 @@ eunit(Config, AppFile) ->
end
end,
%% Make sure ?EUNIT_DIR/ directory exists (tack on dummy module)
ok = filelib:ensure_dir(?EUNIT_DIR ++ "/foo"),
+ ok = filelib:ensure_dir(ebin_dir() ++ "/foo"),
%% Setup code path prior to compilation so that parse_transforms and the like
%% work properly. Also, be sure to add ebin_dir() to the END of the code path
@@ -74,8 +74,9 @@ eunit(Config, AppFile) ->
end
end,
- %% Make sure ?EUNIT_DIR/ directory exists (tack on dummy module)
+ %% Make sure ?EUNIT_DIR/ and ebin/ directory exists (tack on dummy module)
ok = filelib:ensure_dir(?EUNIT_DIR ++ "/foo"),